SystemOrganization addCategory: #ConfigurationOfMarea!

Object subclass: #ConfigurationOfMarea
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMarea'!

!ConfigurationOfMarea class methodsFor: 'private' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMarea class methodsFor: 'private' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
ensureMetacello
        "Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
         Gofer API), then load the latest version of Metacello itself."

        Smalltalk at: #MetacelloProject ifAbsent: [ | error |
                "list of repositories to try, in case primary repository is not accessible"
                (Array 
                        with: 'http://www.squeaksource.com/MetacelloRepository' 
                        with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
                                ([
                                        Smalltalk at: #Gofer ifAbsent: [
                                        "Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
                                                self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
                                        Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
                                                gofer := goferClass new
                                                        url: repositoryUrl;
                                                        yourself.
                                                [ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
                                                gofer load ]]
                                                        on: Error
                                                        do: [ :ex |
                                                                error := ex.
                                                                Transcript 
                                                                        cr; 
                                                                        show: 'failed ensureMetacello: ';
                                                                        show: ex description printString;
                                                                        show: '...retrying'.
                                                                "try again"
                                                                ex return: nil ]) ~~ nil
                                        ifTrue: [
                                                "load 'default' group of Metacello"
                                                (Smalltalk at: #ConfigurationOfMetacello) perform: #load.
                                                ^self ]].
                "shouldn't get here unless the load failed ... throw an error"
                self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfMarea class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfMarea class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMarea class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMarea class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
project

	^self new project! !

!ConfigurationOfMarea methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 10/22/2010 17:35'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		
		spec repository: 'http://www.squeaksource.com/Marea'.
		
		spec project: 'UnusedObjects' with: [
				spec
					className: 'ConfigurationOfUsedObjects';
					loads: #('default' );
					file: 'ConfigurationOfUsedObjects';
					repository: 'http://www.squeaksource.com/UsedObjects' ].
		
		spec project: 'UnusedObjectsVM'
					copyFrom: 'UnusedObjects'
					with: [ spec loads: #('ALL') ].	
			
		
		spec package: 'SimpleLogger'.
		spec package: 'MareaLogger' with: [ spec requires: #('SimpleLogger') ].
		spec package: 'MareaMocks' with: [ spec requires: #('MareaLogger') ].
		spec package: 'Proxies' with: [ spec requires: #('MareaLogger') ].	
		spec package: 'ProxiesTests' with: [ spec requires: #('Proxies'  'MareaMocks' ) ].	
								
	
		spec
 			group: 'default' with: #('UnusedObjects' 'ProxiesGroup' 'SimpleLogger' );
			group: 'ProxiesGroup' with: #( 'Proxies' 'ProxiesTests');
			group: 'UnusedObjectsGroup' with: #('UnusedObjects' 'UnusedObjectsVM');
			group: 'All with VM' with: #('UnusedObjects' 'UnusedObjectsVM' 'ProxiesGroup' 'SimpleLogger').
			
		
	]! !

!ConfigurationOfMarea methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfMarea methodsFor: 'versions' stamp: 'MarianoMartinezPeck 10/20/2010 16:19'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Mariano Martinez Peck'.
		spec description: ' '.
	].
	
	spec for: #pharo do: [		
				
		spec project: 'VMMakerOriginal' with: '1.4'.
		
		spec package: 'UnusedObject' with: 'UnusedObject-MarianoMartinezPeck.50'.
		spec package: 'UnusedObjectTests' with: 'UnusedObjectTests-MarianoMartinezPeck.15'.
		spec package: 'UnusedObjectVMMaker' with: 'UnusedObjectVMMaker-MarianoMartinezPeck.2'.
		
					
		
	]
			! !
